/*============================================================================

The Medical Imaging Interaction Toolkit (MITK)

Copyright (c) German Cancer Research Center (DKFZ)
All rights reserved.

Use of this source code is governed by a 3-clause BSD license that can be
found in the LICENSE file.

============================================================================*/

#ifndef mitkNumericTypes_h
#define mitkNumericTypes_h

#include "mitkAffineTransform3D.h"
#include "mitkEqual.h"
#include "mitkMatrix.h"
#include "mitkNumericConstants.h"
#include "mitkPoint.h"
#include "mitkQuaternion.h"
#include "mitkVector.h"

// this include hold the old deprecated ways to convert from itk 2 vtk and the likes.
// calls to these functions shall be removed in future bugsquashings so that this include can be removed.
#include "mitkVectorDeprecated.h"

#endif
